Module: PluginTestHelper::Generator

Defined in:
lib/plugin_test_helper/generator.rb

Overview

The base generator for creating parts of the test application. The first argument of the generator is always the name of the plugin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#plugin_name ⇒ Object

Returns the value of attribute plugin_name.



7
8
9
# File 'lib/plugin_test_helper/generator.rb', line 7

def plugin_name
  @plugin_name
end

Instance Method Details

#initialize(*runtime_args) ⇒ Object

:nodoc:



9
10
11
12
# File 'lib/plugin_test_helper/generator.rb', line 9

def initialize(*runtime_args) #:nodoc:
  @plugin_name = runtime_args.first.shift if runtime_args.first.is_a?(Array)
  super(*runtime_args)
end