Class: PluginTestHelper::PluginLocator
- Inherits:
-
Rails::Plugin::Locator
- Object
- Rails::Plugin::Locator
- PluginTestHelper::PluginLocator
- Defined in:
- lib/plugin_test_helper/plugin_locator.rb
Overview
Assists in the initialization process by locating the plugin being tested so that it is tested as if the plugin were loaded in a regular app
Instance Method Summary collapse
Instance Method Details
#plugins ⇒ Object
5 6 7 |
# File 'lib/plugin_test_helper/plugin_locator.rb', line 5 def plugins [Rails::Plugin.new(File.('.'))] end |